setup.py

branch
eric7
changeset 8314
e3642a6a1e71
parent 8288
809d5d5ac2ba
child 8318
962bce857696
--- a/setup.py	Sat May 15 19:01:16 2021 +0200
+++ b/setup.py	Sat May 15 20:08:03 2021 +0200
@@ -19,7 +19,7 @@
 
 from setuptools import setup, find_packages
 
-installInfoName = "eric6installpip.json"
+installInfoName = "eric7installpip.json"
 
 ######################################################################
 ## some helper functions below
@@ -79,21 +79,21 @@
     if sys.platform.startswith('linux'):
         dataFiles = [
             ('share/applications', [
-                'linux/eric6.desktop',
-                'linux/eric6_browser.desktop',
+                'linux/eric7.desktop',
+                'linux/eric7_browser.desktop',
             ]),
             ('share/icons', [
-                'eric6/icons/breeze-dark/eric.svg',
-                'eric6/icons/breeze-dark/ericWeb48.svg'
+                'eric7/icons/breeze-dark/eric.svg',
+                'eric7/icons/breeze-dark/ericWeb48.svg'
             ]),
-            ('share/appdata', ['linux/eric6.appdata.xml']),
-            ('share/metainfo', ['linux/eric6.appdata.xml']),
+            ('share/appdata', ['linux/eric7.appdata.xml']),
+            ('share/metainfo', ['linux/eric7.appdata.xml']),
         ]
     elif sys.platform.startswith(("win", "cygwin")):
         dataFiles = [
             ('scripts', [
-                'eric6/pixmaps/eric6.ico',
-                'eric6/pixmaps/ericWeb48.ico'])
+                'eric7/pixmaps/eric7.ico',
+                'eric7/pixmaps/ericWeb48.ico'])
         ]
     else:
         dataFiles = []
@@ -278,12 +278,12 @@
 ######################################################################
 
 Version = getVersion()
-sourceDir = os.path.join(os.path.dirname(__file__), "eric6")
+sourceDir = os.path.join(os.path.dirname(__file__), "eric7")
 infoFileName = os.path.join(sourceDir, "UI", "Info.py")
 appdataFileName = os.path.join(os.path.dirname(__file__), "linux",
-                               "eric6.appdata.xml")
+                               "eric7.appdata.xml")
 if sys.argv[1].startswith("bdist"):
     # prepare the sources under "eric6" for building the wheel file
     print("preparing the sources...")       # __IGNORE_WARNING_M801__
     cleanupSource(sourceDir)
     compileUiFiles(sourceDir)
@@ -357,42 +357,42 @@
     zip_safe=False,
     package_data={
         "": getPackageData(
-            "eric6",
+            "eric7",
             [".png", ".svg", ".svgz", ".xpm", ".ico", ".gif", ".icns", ".txt",
              ".tmpl", ".html", ".qch", ".css", ".qss", ".e4h", ".e6h", ".ehj",
              ".api", ".bas", ".dat", ".xbel", ".xml", ".js"]
-        ) + ["i18n/eric6_de.qm", "i18n/eric6_en.qm", "i18n/eric6_es.qm",
-             "i18n/eric6_ru.qm",
+        ) + ["i18n/eric7_de.qm", "i18n/eric7_en.qm", "i18n/eric7_es.qm",
+             "i18n/eric7_ru.qm",
              installInfoName,
              ]
     },
     entry_points={
         "gui_scripts": [
-            "eric6 = eric6.eric6:main",
-            "eric6_browser = eric6.eric6_browser:main",
-            "eric6_compare = eric6.eric6_compare:main",
-            "eric6_configure = eric6.eric6_configure:main",
-            "eric6_diff = eric6.eric6_diff:main",
-            "eric6_editor = eric6.eric6_editor:main",
-            "eric6_hexeditor = eric6.eric6_hexeditor:main",
-            "eric6_iconeditor = eric6.eric6_iconeditor:main",
-            "eric6_plugininstall = eric6.eric6_plugininstall:main",
-            "eric6_pluginrepository = eric6.eric6_pluginrepository:main",
-            "eric6_pluginuninstall = eric6.eric6_pluginuninstall:main",
-            "eric6_qregularexpression = eric6.eric6_qregularexpression:main",
-            "eric6_re = eric6.eric6_re:main",
-            "eric6_shell = eric6.eric6_shell:main",
-            "eric6_snap = eric6.eric6_snap:main",
-            "eric6_sqlbrowser = eric6.eric6_sqlbrowser:main",
-            "eric6_tray = eric6.eric6_tray:main",
-            "eric6_trpreviewer = eric6.eric6_trpreviewer:main",
-            "eric6_uipreviewer = eric6.eric6_uipreviewer:main",
-            "eric6_unittest = eric6.eric6_unittest:main",
+            "eric7 = eric7.eric7:main",
+            "eric7_browser = eric7.eric7_browser:main",
+            "eric7_compare = eric7.eric7_compare:main",
+            "eric7_configure = eric7.eric7_configure:main",
+            "eric7_diff = eric7.eric7_diff:main",
+            "eric7_editor = eric7.eric7_editor:main",
+            "eric7_hexeditor = eric7.eric7_hexeditor:main",
+            "eric7_iconeditor = eric7.eric7_iconeditor:main",
+            "eric7_plugininstall = eric7.eric7_plugininstall:main",
+            "eric7_pluginrepository = eric7.eric7_pluginrepository:main",
+            "eric7_pluginuninstall = eric7.eric7_pluginuninstall:main",
+            "eric7_qregularexpression = eric7.eric7_qregularexpression:main",
+            "eric7_re = eric7.eric7_re:main",
+            "eric7_shell = eric7.eric7_shell:main",
+            "eric7_snap = eric7.eric7_snap:main",
+            "eric7_sqlbrowser = eric7.eric7_sqlbrowser:main",
+            "eric7_tray = eric7.eric7_tray:main",
+            "eric7_trpreviewer = eric7.eric7_trpreviewer:main",
+            "eric7_uipreviewer = eric7.eric7_uipreviewer:main",
+            "eric7_unittest = eric7.eric7_unittest:main",
         ],
         "console_scripts": [
-            "eric6_api = eric6.eric6_api:main",
-            "eric6_doc = eric6.eric6_doc:main",
-            "eric6_post_install = eric6.eric6_post_install:main"
+            "eric7_api = eric7.eric7_api:main",
+            "eric7_doc = eric7.eric7_doc:main",
+            "eric7_post_install = eric7.eric7_post_install:main"
         ],
     },
 )
@@ -278,12 +278,12 @@
 if sys.argv[1].startswith("bdist"):
-    # prepare the sources under "eric6" for building the wheel file
+    # prepare the sources under "eric7" for building the wheel file
     print("preparing the sources...")       # __IGNORE_WARNING_M801__
     cleanupSource(sourceDir)

eric ide

mercurial